@@ -8,7 +8,7 @@ from muffin.plugins import BasePlugin
 from apiclient import APIClient
 
 
-__version__ = "3.1.1"
+__version__ = "3.1.2"
 __project__ = "muffin-apiclient"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -50,12 +50,11 @@ class Plugin(BasePlugin):
 
     def setup(self, app: Application, **options):
         """Setup API Client."""
-        self.cfg.update_from_dict({
-            'root_url': self.cfg.root_url or self.root_url,
-            'timeout': self.cfg.timeout or self.timeout,
-        })
-
         super().setup(app, **options)
+        self.cfg.update(
+            root_url=self.cfg.root_url or self.root_url,
+            timeout=self.cfg.timeout or self.timeout,
+        )
         self.client = APIClient(
             self.cfg.root_url, timeout=self.cfg.timeout,
             backend_type=self.cfg.backend_type,
